@@ -146,7 +146,8 @@ class Client:
                     to be added
         '''
         #Client ID, Patient ID, and MRN are immutable
-        if key == "CLIENT_ID" or key == "MRN" or key == "PATIENT_ID" or key == "PATIENT_PARTITION":
+        if key == "CLIENT_ID" or key == "MRN" or \
+            key == "PATIENT_ID" or key == "PATIENT_PARTITION" or key == 'DATE_INSERTED':
             return ''
 
         if self.overwrite == False and patient_data_value is None:
@@ -193,7 +194,8 @@ class Client:
         # compare, the changes in the two records
         for k in patient_data:
             if k == "CLIENT_ID" or k == "MRN" or k == "PATIENT_ID" \
-            or k == "UPDATED_AT" or k == "CHECKSUM" or k == "PATIENT_PARTITION":
+            or k == "UPDATED_AT" or k == "CHECKSUM" or \
+                k == "PATIENT_PARTITION" or k == 'DATE_INSERTED':
                 continue
 
             elif not self.__is_updateable(patient_data[k], patient_row.get(k)):
