@@ -82,6 +82,7 @@ class Client():
         patient_data = self.__convert_hl7_sex_code(patient_data)
         patient_data = self.__transform_date(patient_data)
         patient_data = self.__create_checksum(patient_data)
+        patient_data = self.__add_date_inserted(patient_data)
 
         return self.__create_partition(patient_data)
 
@@ -174,11 +175,28 @@ class Client():
         patient_data['CHECKSUM'] = dhash.hexdigest()
         return patient_data
 
+    def __add_date_inserted(self, patient_data: dict) -> dict:
+        ''' Creates a field in the patient data representing the date it was inserted
+        
+        This field is created because it helps cluster the patient data on the patient de-duplication
+        service. This clustering will both save time and money as the PATIENTS table grows and needs to
+        be queried.
+
+        Args:
+            patient_data (dict): The dictionary containing the patients data
+        Returns:
+            dict: The updated dictionary
+        '''
+        date = datetime.date.today()
+        patient_data['DATE_INSERTED'] = str(date)
+
+        return patient_data
+
     def __create_partition(self, patient_data: dict) -> dict:
         ''' creates the table partition field from the patient_id
 
-        The partition is created from converting the PATIENT_ID (uuid gen4) with mod 4000
-        (max partitions for BQ table)
+        The partition is created from converting the PATIENT_ID 
+        (35 characters) with mod 3990
 
         Args:
             patient_data (dict): The dictionary containing the patients data
@@ -186,8 +204,8 @@ class Client():
             dict: The updated dictionary
         '''
 
-        patient_id = int(patient_data['PATIENT_ID'], base=16)
-        patient_partition = patient_id % 4000
+        patient_id = int(patient_data['PATIENT_ID'][0:35], base=16)
+        patient_partition = patient_id % 3990
         patient_data['PATIENT_PARTITION'] = patient_partition
         return patient_data
 
