@@ -4,6 +4,7 @@
 #
 
 from google.api_core.exceptions import NotFound
+from google.api_core.exceptions import ServiceUnavailable
 
 from google.cloud import compute_v1
 from google.cloud.compute_v1.types import Items
@@ -12,6 +13,7 @@ from google.cloud.compute_v1.types import ServiceAccount
 from google.cloud.compute_v1.types import AccessConfig
 from indxdatalaketools import Helpers
 from indxdatalaketools.GoogleClients.GoogleClients import GcpClients
+from indxdatalaketools.GoogleClientWrappers.retry_decorator import retry_decorator
 
 
 class Wrapper:
@@ -25,6 +27,7 @@ class Wrapper:
         self.__compute_engine_operation_client = GcpClients.instance(
         ).get_compute_engine_operation_client()
 
+    @retry_decorator()
     def check_if_vm_exists(self, vm_name, zone_id, project_id):
         '''
             Function that checks if a VM exists
@@ -38,6 +41,8 @@ class Wrapper:
                                                       zone=zone_id,
                                                       instance=vm_name)
             return True
+        except ServiceUnavailable:
+            raise ServiceUnavailable('503 retry')
         except NotFound:
             return False
 
@@ -124,6 +129,7 @@ class Wrapper:
 
         return request
 
+    @retry_decorator()
     def create_compute_engine_instance_with_request(self, request):
         ''' 
             Creates a compute engine instance with a 
@@ -136,11 +142,14 @@ class Wrapper:
         try:
             return self.__compute_engine_instance_client.\
                 insert(request=request)
+        except ServiceUnavailable as e:
+            raise ServiceUnavailable('503 retry')
         except Exception as exception:
             Helpers.print_error('Could not create Compute Engine Instance ' +
                                 str(exception))
             return None
 
+    @retry_decorator()
     def stop_compute_engine_instance(self, instance_name, zone_id, project_id):
         '''
             Stops a compute engine Instance
@@ -155,6 +164,8 @@ class Wrapper:
         try:
             return self.__compute_engine_instance_client.\
             stop(project=project_id, zone=zone_id, instance=instance_name)
+        except ServiceUnavailable as e:
+            raise ServiceUnavailable('503 retry')
         except Exception as e:
             Helpers.print_error('Failed To Stop instance ' + str(e))
             return None
