@@ -5,7 +5,9 @@
 
 import google_crc32c
 from indxdatalaketools.GoogleClients.GoogleClients import GcpClients
+from google.api_core.exceptions import ServiceUnavailable
 from indxdatalaketools.Helpers import print_error
+from indxdatalaketools.GoogleClientWrappers.retry_decorator import retry_decorator
 
 
 class Wrapper:
@@ -15,6 +17,7 @@ class Wrapper:
         ''' Nothin to initialize'''
         pass
 
+    @retry_decorator()
     def get_secret(self, project_id, secret_id, version_id='latest'):
         '''
             Function that returns a secret found in secret manager
@@ -37,9 +40,10 @@ class Wrapper:
                 print_error("Data corruption detected for secret id" +
                             secret_id)
                 return ''
-
             payload = response.payload.data.decode("UTF-8")
             return payload
+        except ServiceUnavailable:
+            raise ServiceUnavailable('503 retry')
         except Exception as err:
             print_error('problem accessing secret ' + name + ' ' + str(err))
             return ''
